==> idom_jupyter-0.6.1.tar.gz: idom_jupyter-0.6.1/idom_jupyter/__init__.py <==
from ._version import version_info  # noqa
from ._version import __version__  # noqa

from . import jupyter_server_extension
from .widget import LayoutWidget, widgetize, run, set_jupyter_server_base_url
from .ipython_extension import load_ipython_extension, unload_ipython_extension


__all__ = [
    "LayoutWidget",
    "widgetize",
    "run",
    "load_ipython_extension",
    "unload_ipython_extension",
    "set_jupyter_server_base_url",
    "jupyter_server_extension",
]


def _jupyter_labextension_paths():
    """Called by Jupyter Lab Server to detect if it is a valid labextension and
    to install the widget
    Returns
    =======
    src: Source directory name to copy files from. Webpack outputs generated files
        into this directory and Jupyter Lab copies from this directory during
        widget installation
    dest: Destination directory name to install widget files to. Jupyter Lab copies
        from `src` directory into <jupyter path>/labextensions/<dest> directory
        during widget installation
    """
    return [
        {
            "src": "labextension",
            "dest": "idom-client-jupyter",
        }
    ]


def _jupyter_nbextension_paths():
    """Called by Jupyter Notebook Server to detect if it is a valid nbextension and
    to install the widget

    Returns
    =======
    section: The section of the Jupyter Notebook Server to change.
        Must be 'notebook' for widget extensions
    src: Source directory name to copy files from. Webpack outputs generated files
        into this directory and Jupyter Notebook copies from this directory during
        widget installation
    dest: Destination directory name to install widget files to. Jupyter Notebook copies
        from `src` directory into <jupyter path>/nbextensions/<dest> directory
        during widget installation
    require: Path to importable AMD Javascript module inside the
        <jupyter path>/nbextensions/<dest> directory
    """
    return [
        {
            "section": "notebook",
            "src": "nbextension",
            "dest": "idom-client-jupyter",
            "require": "idom-client-jupyter/extension",
        }
    ]

==> idom_jupyter-0.7.0.tar.gz: idom_jupyter-0.7.0/idom_jupyter/__init__.py <==
from ._version import version_info  # noqa
from ._version import __version__  # noqa

from . import jupyter_server_extension
from .import_resources import setup_import_resources
from .widget import LayoutWidget, widgetize, run, set_import_source_base_url
from .ipython_extension import load_ipython_extension, unload_ipython_extension


__all__ = [
    "LayoutWidget",
    "widgetize",
    "run",
    "load_ipython_extension",
    "unload_ipython_extension",
    "set_import_source_base_url",
    "jupyter_server_extension",
]


setup_import_resources()


def _jupyter_labextension_paths():
    """Called by Jupyter Lab Server to detect if it is a valid labextension and
    to install the widget
    Returns
    =======
    src: Source directory name to copy files from. Webpack outputs generated files
        into this directory and Jupyter Lab copies from this directory during
        widget installation
    dest: Destination directory name to install widget files to. Jupyter Lab copies
        from `src` directory into <jupyter path>/labextensions/<dest> directory
        during widget installation
    """
    return [
        {
            "src": "labextension",
            "dest": "idom-client-jupyter",
        }
    ]


def _jupyter_nbextension_paths():
    """Called by Jupyter Notebook Server to detect if it is a valid nbextension and
    to install the widget

    Returns
    =======
    section: The section of the Jupyter Notebook Server to change.
        Must be 'notebook' for widget extensions
    src: Source directory name to copy files from. Webpack outputs generated files
        into this directory and Jupyter Notebook copies from this directory during
        widget installation
    dest: Destination directory name to install widget files to. Jupyter Notebook copies
        from `src` directory into <jupyter path>/nbextensions/<dest> directory
        during widget installation
    require: Path to importable AMD Javascript module inside the
        <jupyter path>/nbextensions/<dest> directory
    """
    return [
        {
            "section": "notebook",
            "src": "nbextension",
            "dest": "idom-client-jupyter",
            "require": "idom-client-jupyter/extension",
        }
    ]
